@@ -96,6 +96,51 @@ describe 'concat::fragment', :type => :define do
     end
   end # source =>
 
+  context 'order =>' do
+    ['', '42', 'a', 'z'].each do |order|
+      context '\'\'' do
+        it_behaves_like 'fragment', 'motd_header', {
+          :order  => order,
+          :target => '/etc/motd',
+        }
+      end
+    end
+
+    context 'false' do
+      let(:title) { 'motd_header' }
+      let(:params) {{ :order => false, :target => '/etc/motd' }}
+
+      it 'should fail' do
+        expect { catalogue }.to raise_error(Puppet::Error, /is not a string or integer/)
+      end
+    end
+
+    context '123:456' do
+      let(:title) { 'motd_header' }
+      let(:params) {{ :order => '123:456', :target => '/etc/motd' }}
+
+      it 'should fail' do
+        expect { catalogue }.to raise_error(Puppet::Error, /cannot contain/)
+      end
+    end
+    context '123/456' do
+      let(:title) { 'motd_header' }
+      let(:params) {{ :order => '123/456', :target => '/etc/motd' }}
+
+      it 'should fail' do
+        expect { catalogue }.to raise_error(Puppet::Error, /cannot contain/)
+      end
+    end
+    context '123\n456' do
+      let(:title) { 'motd_header' }
+      let(:params) {{ :order => "123\n456", :target => '/etc/motd' }}
+
+      it 'should fail' do
+        expect { catalogue }.to raise_error(Puppet::Error, /cannot contain/)
+      end
+    end
+  end # order =>
+
   context 'more than one content source' do
     context 'source and content' do
       let(:title) { 'motd_header' }
@@ -108,7 +153,7 @@ describe 'concat::fragment', :type => :define do
       end
 
       it 'should fail' do
-        expect { catalogue }.to raise_error(Puppet::Error, /Can't use 'source' and 'content' at the same time/)
+        expect { catalogue }.to raise_error(Puppet::Error, /Can\'t use \'source\' and \'content\' at the same time/m)
       end
     end
   end # more than one content source
